function [u,udot]=mphgetu(model,varargin)
% MPHGETU Return solution vector
%
%   U = MPHGETU(MODEL,...) returns the solution vector U for the default
%   solution data set.
%
%   [U,UDOT] = MPHGETU(MODEL,...) returns in addition UDOT, which is the 
%   time derivative of the solution vector. This syntax is available for a
%   time-dependent solution only.
%
%   For a time-dependent and parametric analysis type, the last solution is
%   returned by default.
%   For an Eigenvalue analysis type the first solution number is returned
%   by default.
%
%   Property    Value/{Default}                Description
%   -----------------------------------------------------------------------
%   soltag      String {''}                    Solver node tag
%   solnum      Positive integer vector {[]}   Solution for evaluation
%   type        String                         Solution type
%   matrix      'off' | {'on'}                 Store as matrix if possible
%
%   The soltag property set the solution dataset to use associated to use
%   with the defined solver node.
%
%   Type is used to select the solution type. This is 'Sol' by default.
%   The valid types are: 'sol' (main solution), 'reacf' (reaction force),
%   'adj' (adjoint solution), 'fsens' (functional sensitivity)
%   and 'sens' (forward sensitivity).
%
%   If solnum is a vector and the result has been obtained with the same
%   mesh then the solution will be stored in a matrix if the matrix option
%   is set to 'on'
%
%
%   Example 1: Extract the solution vector of a stationary problem
%     % Load model_tutorial_llmatlab.mph:
%     model = mphopen('model_tutorial_llmatlab');
%     model.mesh('mesh1').autoMeshSize(8);
%     % Create a stationary study:
%     std = model.study.create('std');
%     std.feature.create('stat','Stationary');
%     % Run the study:
%     std.run;
%
%     % Extract the solution vector:
%     U = mphgetu(model);
%
%     % Extract the reaction force vector:
%     reacf = mphgetu(model,'type','reacf');
% 
%   Example 2: Extract the solution vector of a combined problem, 
%   parametric sweep and transient study
%     % Load model_tutorial_llmatlab.mph:
%     model = mphopen('model_tutorial_llmatlab');
%     model.mesh('mesh1').autoMeshSize(8);
%     % Create a study combining a parametric sweep and a transient
%     % study step:
%     std = model.study.create('std');
%     param = std.feature.create('param','Parametric');
%     time = std.feature.create('time','Transient');
%     % Set the time stepping and the parametric sweep parameters:
%     time.set('tlist', 'range(0,1,25)');
%     param.setIndex('pname','power',0).setIndex('plistarr','30 60 90',0);
%     % Run the study:
%     std.run;
%
%     % Extract the solution vectors for the first and the last time step:
%     U = mphgetu(model,'solnum',[1,26]);
%
%     % Extract the solution vector computed with power set to 30:
%     U = mphgetu(model,'soltag','sol3');
%
%   See also: mphsolinfo

%   Copyright 2010-2023 COMSOL
