function [data,fname]=mphmatrix(model,soltag,varargin)
% MPHMATRIX Get model matrices
%
%   STR = MPHMATRIX(MODEL,SOLTAG,'Out',{'A'}) returns a MATLAB structure
%   STR containing the matrix A assembled using the solver node defined
%   with the tag SOLTAG and accessible as STR.A. A being taken from the Out
%   property list.
%
%   STR = MPHMATRIX(MODEL,SOLTAG,'Out',{'A','B',...},...) returns a
%   MATLAB structure STR containing the matrices A, B, ... assembled using
%   the solver node defined with the tag SOLTAG and accessible as STR.A and
%   STR.B. A and B being taken from the Out property list.
%
%   Valid property/value pairs include:
%   Property      Value/{Default}             Description
%   -----------------------------------------------------------------------
%   complexfun    'on' | {'off'}              Use complex-valued functions
%                                             with real input
%   extractafter  solution feature tag |      Specify where to extract
%                 {end}                       the matrices
%   eigname       String{'lambda'}            Eigenvalue name
%   eigref        Double{0}                   Value of eigenvalue
%                                             linearization point
%   initmethod    {'init'} | 'sol'            Use linearisation point
%   initsol       soltag | {'zero'}           Solution to use for
%                                             linearisation
%   matherr       {'on'} | 'off'              Error for undefined operations
%   nullfun       'flnullorth' | 		      Null-space function
%			      'flspnull' |
%                 'explicitsp' |
%                 'explicitorth' |
%                 {'auto'}
%   out           'K'                         Stiffness matrix
%                 'L'                         Load vector
%                 'M'                         Constraint vector
%                 'N'                         Constraint Jacobian
%                 'D'                         Damping matrix
%                 'E'                         Mass matrix
%                 'NF'                        Constraint force Jacobian
%                 'NP'                        Optimization constraint
%                                             Jacobian(*)
%                 'MP'                        Optimization constraint vector(*)
%                 'MLB'                       Lower bound constraint vector(*)
%                 'MUB'                       Upper bound constraint vector(*)
%                 'Kc'                        Eliminated stiffness matrix
%                 'Lc'                        Eliminated load vector
%                 'Dc'                        Eliminated damping matrix
%                 'Ec'                        Eliminated mass matrix
%                 'Null'                      Constraint null-space basis
%                 'Nullf'                     Constraint force null-space
%                                             matrix
%                 'ud'                        Particular solution ud
%                 'uscale'                    Scale vector
%   rowscale      {'on'} | 'off'              Row equilibration
%   solnum        {'auto'} | 'first' | 	      Solution number
%				  'last' | 'interp' |
%			      'manual' | Positive Integer                    
%   study         {first study}               Study to use when using
%                                             initmethod
%   symmetry      'on' | 'off' | {'auto'}     Symmetric matrices
%                  'hermitian'
%
%   (*) Require the Optimization module
%
%   Note that the assembly of the eliminated matrices uses the current
%   solution vector as scaling method. To get the unscaled eliminated
%   system matrices, it is required to set the scaling method to 'none' in
%   the variables step of the solver configuration node.
%   The matrices are assembled using the current solution available as 
%   linearization point unless the initmethod property is provided. 
%   In case of the presence of a solver step node you need to either 
%   disable the solver step node in the model or set the property 
%   extractafter with the Dependent Variable node tag.
%   In case the matrices are assembled after a solver step node (which is 
%   the case by default), the load vector corresponds then to the residual 
%   of the problem.
%
%
%   Example 1: Evaluate the system matrices of a stationary problem
%     % Load model_tutorial_llmatlab.mph:
%     model = mphopen('model_tutorial_llmatlab');
%     model.mesh('mesh1').autoMeshSize(8);
%     % Add a Stationary study to the model and compute the solution
%     std = model.study.create('std1');
%     std.feature.create('stat', 'Stationary');
%     std.run;
%
%     % Get the stationary matrix system, use the initial solution as
%     % linearization point:
%     str = mphmatrix(model,'sol1','out',{'K','L','M','N'},...
%        'initmethod','init');
%     % Display the sparsity of the stiffness matrix and the constraint
%     % vector
%     subplot(2,1,1); spy(str.K);subplot(2,1,2);spy(str.N)
%     % Compute the total load applied in the matrix system:
%     Q = sum(str.L)
%
%     % Get the eliminated matrix system, use the initial solution as
%     % linearization point:
%     str = mphmatrix(model,'sol1','out',{'Kc'},'initmethod','init');
%     % Compare the sparsity between the eliminated and non-eliminated
%     % stiffness matrix:
%     subplot(2,1,1); hold on; spy(str.Kc,'r')
%
%     % Evaluate the eliminated load vector using the current solution as
%     % linearization point:
%     str = mphmatrix(model,'sol1','out',{'Lc'},'initmethod','sol');
%
%   Example 2: Evaluate the system matrices of a dynamic problem
%     % Load model_tutorial_llmatlab.mph
%     model = mphopen('model_tutorial_llmatlab');
%     model.mesh('mesh1').autoMeshSize(8);
%     % Add a Transient study to the current model
%     std = model.study.create('std1');
%     time = std.feature.create('time', 'Transient');
%     time.set('tlist', 'range(0,1,25)');
%     model.param.set('timestep', '1[s]');
%     std.run
%
%     % Get the dynamic matrix system:
%     str = mphmatrix(model,'sol1','out',{'E','D','K','L','M','N'});
%     % Display the sparsity of the mass and stiffness matrices:
%     subplot(1,2,1); spy(str.D); subplot(1,2,2); spy(str.K);
%
%     % Get the elimanted dynamic matrix system:
%     str = mphmatrix(model,'sol1','out',{'Ec','Dc','Kc','Lc','M','N'});
%
%     % solve the model to get linearization point
%     std.run
%
%     % Assemble the Jacobian using solution number 15 as linearization
%     % point:
%     str = mphmatrix(model,'sol1','out',{'K'},...
%        'initmethod','sol','initsol','sol1','solnum',15);
%
%     % Assemble the Jacobian using the zero vector as linearization point:
%     str = mphmatrix(model,'sol1','out',{'K'},...
%        'initmethod','sol','initsol','zero');
%
%   See also: mphstate, mphxmeshinfo, mphinputmatrix

%   Copyright 2010-2023 COMSOL
