function [stats,data]=mphmeshstats(model,meshtag,varargin)
% MPHMESHSTATS Return mesh statistics and mesh data information
%
%   STATS = MPHMESHSTATS(MODEL) returns mesh statistics of the model mesh
%   case in the structure STATS.
%
%   STATS = MPHMESHSTATS(MODEL,MESHTAG,...) returns mesh statistics of a
%   mesh case MESHTAG in the structure STATS.
%
%   [STATS,DATA] = MPHMESHSTATS(MODEL,MESHTAG,...) returns in addition the
%   mesh data information in the structure DATA.
%
%   Valid property/value pairs include:
%   Property          Value/{Default}               Description
%   -----------------------------------------------------------------------
%   entity(*)         {[]} | 'domain' |             Selected entity type
%                     'boundary' |
%                     'edge' | 'point'
%   qualityhistogram  int | {20}                    Number of bins in the 
%                                                   quality distribution 
%                                                   histogram
%   qualitymeasure    'condition' | 'growth' |      Quality measure
%                     'maxangle' | {'skewness'} |
%                     'volcircum' | 'vollength'
%   selection         String | Positive integer     Selection tag or entity 
%                     array | {[]}                  number
%   type(*)           'vtx' | 'edg' | 'tri' |       Restrict statistics to
%                     'quad' | 'tet' | 'pyr' |      element types
%                     'prism' | 'hex' | {''}        
%
%   (*) Selection and/or Entity properties can not be set if the DATA
%   structure is returned.
%
%   The structure STATS contains the following fields:
%   Field                    Description
%   -----------------------------------------------------------------------
%   meshtag                  Mesh case tag
%   geomtag                  Geometry tag
%   geometricmodel           Geometric model used by the mesh sequence
%   component                Component tag
%   componentgeometricmodel  Geometric model used by the physics
%   current                  Current mesh feature tag
%   isempty                  Is the mesh empty?
%   hasproblems              Does the mesh have problems?
%   islocked                 Is the mesh locked?
%   iscomplete               Is the mesh built to completion?
%   secondorderelements      Does the mesh have second order elements?
%   sdim                     Space dimension
%   contributing             Contributing physics or multiphysics interface 
%                            for the physics-controlled mesh
%   types                    Element types present in the mesh
%   numelem                  Number of elements for each mesh type 
%   qualitymeasure           Quality measure
%   minquality               Minimum quality
%   meanquality              Mean quality
%   qualitydistr             Quality distribution
%   minvolume                Volume/area/length of the smallest element
%   maxvolume                Volume/area/length of the largest element
%   volume                   Volume/area/length of the mesh
%   maxgrowthrate            Maximum growth rate(*)
%   meangrowthrate           Mean growth rate(*)
%
%   (*) Provides statistics for the entire selection regardless of the
%   element type property
%
%   The structure DATA contains the following fields:
%   Field          Description
%   -----------------------------------------------------------------------
%   vertex         Coordinates of mesh vertices
%   elem           Cell array of definition of each element type
%   elementity     Entity information for each element type
%
%   Example :
%     % Load model_tutorial_llmatlab.mph:
%     model = mphopen('model_tutorial_llmatlab');
%     % Create a default mesh:
%     model.mesh.run;
%
%     % Get the mesh statistics:
%     stats = mphmeshstats(model)
%     % Show the mesh quality distribution in a figure:
%     bar(linspace(0,1,20),stats.qualitydistr)
%
%     % Get the mesh statistics and the mesh data:
%     [stats,data] = mphmeshstats(model);
%     % Show the element vertices in a plot:
%     plot3(data.vertex(1,:), data.vertex(2,:), data.vertex(3,:), '.')
%     axis equal
%     % Get the number of edge element:
%     numedgeelem = stats.numelem(strcmp(stats.types,'edg'))
%
%   See also: mphmesh

%   Copyright 2011-2023 COMSOL
