function varargout=mphmin(model,expr,edim,varargin)
% MPHMIN Perform minimun of expressions
%
%   [V1,...,VN] = MPHMIN(MODEL,{E1,...,EN},EDIM,...) evaluates the minimum
%   of the string expressions E1,...,EN and returns the result in N
%   matrices V1,...,VN with M rows and P columns. M is the number of inner
%   solutions and P the number of outer solutions. EDIM is the element
%   dimension: 'line', 'surface', 'volume' or as an integer.
%
%   [V1,...,VN,UNIT] = MPHMIN(MODEL,{E1,...,EN},EDIM,...) also returns the
%   units in a 1xN cell array.
%
%   Valid property/value pairs include:
%   Property     Value/{Default}               Description
%   -----------------------------------------------------------------------
%   dataseries    {'none'} | 'average' |       Dataseries operation
%                 'integral' | 'maximum' |
%                 'minimum' | 'rms' |
%                 'stddev' | 'variance'
%   dataset       String {''}                  Data set tag
%   intsurface    'on' | {'off'}               Compute surface integral
%   intvolume     'on' | {'off'}               Compute volume integral
%   matrix        {'on'} | 'off'               Return data as a matrix or
%                                              as a cell array
%   outersolnum   Positive integer {1} |	   Solution number for parametric
%                 'end' | 'all'                sweep
%   position      {'off'} | 'on'               Include position
%   selection     Integer vector | String |    Selection list or named
%                 {'all'}                      selection
%   solnum        Integer vector | 'end' |     Solution for evaluation
%                 {'all'}
%   squeeze       {'on'} | 'off'               Squeeze result
%   t             Double array {''}            Time for evaluation
%   unit          String {''} |                Unit to use for the evaluation
%                 Cell array
%
%   The property solnum is used to select the inner solution number, e.g. when
%   a parametric, eigenvalue or time-dependent solver has been used.
%   The property outersolnum is used to  select the outer solution number, e.g.
%   when a parametric sweep has been used in the study step node.
%   If the matrix property is set to 'off' the output will be cell arrays of
%   length P containing cell arrays of length M.
%
%   See the entry MPHMIN in the LiveLink for MATLAB User's Guide for more
%   information about the property/values.
%
%
%   Example 1:
%     % Load the model model_tutorial_llmatlab.mph:
%     model = mphopen('model_tutorial_llmatlab');
%     % Create a stationary study:
%     std = model.study.create('std');
%     std.feature.create('stat','Stationary');
%     % Run the study study:
%     std.run;
%
%     % Evaluate the minimum temperature in the model domain
%     minT = mphmin(model,'T','volume')
%
%     % Evaluate the minimum temperature on boundary 7
%     minT = mphmin(model,'T','surface','selection',7)
%
%   Example 2: Evaluate minimum of expression using several solution
%     % Load the model model_tutorial_llmatlab.mph:
%     model = mphopen('model_tutorial_llmatlab');
%     % Create a study combining a parametric sweep and a transient
%     % study step:
%     std = model.study.create('std');
%     param = std.feature.create('param','Parametric');
%     time = std.feature.create('time','Transient');
%     % Set the time stepping and the parametric sweep parameters:
%     time.set('tlist', 'range(0,1,25)');
%     param.setIndex('pname','power',0).setIndex('plistarr','30 60 90',0);
%     % Run the study:
%     std.run;
%
%     % Evaluate the minimum of the temperature at every time step computed
%     % with power set to 30:
%     minT = mphmin(model,'T','volume','dataset','dset2')
%
%     % Evaluate the minimum of the temperature at the fifth time step:
%     minT = mphmin(model,'T','volume','dataset','dset2','solnum',5)
%
%     % Evaluate the minimum of the temperature at 10.5 sec and 15.2 sec:
%     minT = mphmin(model,'T','volume','dataset','dset2','t',[10.5, 15.2])
%
%     % Evaluate the minimum of the temperature at every time step computed
%     % with power set to 90:
%     minT = mphmin(model,'T','volume','dataset','dset2','outersolnum',3)
%
%   See also: mphmax, mphmean

%   Copyright 2012-2023 COMSOL
